


#' ---
#' title: Overrepresented motifs in your proteins of interest
#' author: A tool by Alastair Skeffington hosted by Cyverse and making use of the motif-x motif finding engine
#' ---
#'<style>
#'  body {
#'    text-align: justify}
#'</style>


#+ include = FALSE
library(wordcloud)
library(dplyr)
library(ggplot2)
library(ggrepel)
library(gplots)
library(knitr)
library(kableExtra)
library(ComplexHeatmap)
library(matrixStats)
library(energy)
library(tibble)
library(circlize)

#'<br>
#'The main outputs of the program are listed below:
#+ echo = FALSE, warnings=FALSE, messages=FALSE

#'* Mgallo_6 _bgmotifs.txt : counts of each of the overrepresented motifs in each of the proteins in the background sequence set
#'* Mgallo_6 _fgmotifs.txt : counts of each of the overrepresented motifs in each of the proteins in the foreground sequence set
#'* Mgallo_6 _fgenrich.txt : the enrichment of each of the overrepresented motifs in each of the proteins in the foreground sequence set with repspect to the background sequence set
#'* Mgallo_6 _motifsummary.txt : for each overrepresented motif, the enrichemnt in the forgraound sequnces relative to the background; the count of proteins in which it appears and the median count of the motif per  protein
#'* Mgallo_6 _motifs.html : A html summary of the analysis with some helpful plots
#'* Mgallo_6 _Rscript.R : The R script that generated the html output. This can be used as a basis to produce your own custom figures and plots in R
#'* Mgallo_6 _wordclouds.svg : An svg file of the wordclouds from the html report. This can be imported into Inkscape or other software to make publication ready figures
#'* Mgallo_6 _positions.txt: This contains the sequence composistion biases detected by fLPS

#+ echo = FALSE, warnings=FALSE, messages=FALSE

#'<br>
#'The main outputs of the program are the data tables. For convenience these are processed to a html document with
#'some visualizations of the data. However one analysis pipeline can never be appropriate for every dataset,
#'so the R script used to generate these diagrams is also an output of the program. This is to allow you, or an
#'infromatically minded colleague to easily tweak the plots or to develop these analyses further in a way
#'appropriate for your data.
#'<br>
#'The table below shows the motifs that are significantly overrepresented in your protein set of interest (PSOI) compared
#'to the background proteome. In your dataset 89 overrepresented motifs were identified. If you removed the PSOI from the background proteome fasta file
#'which you used as an input, the you may have motifs that are infinitely enriched ('Inf') because they are present
#'in the PSOI but not in the background.
#+ echo = FALSE, fig.height=3, fig.width=6

mots.path = "/working/Mgallo_6_motifsummary.txt"
mots_num.path  = "/working/Mgallo_6_fgmotifs.txt"
fg_enrich.path = "/working/Mgallo_6_fgenrich.txt"
bias.path = "/working/Mgallo_6_positions.txt"

wclname = "Mgallo_6_wordcloud.svg"

flpspval <- 1e-6

dcorco <- 0.65



mots<-read.table(mots.path, sep="\t", header=TRUE)
mots<-mots[,1:4]
mot_num<-read.table(mots_num.path, sep="\t", header=TRUE, row.names=1)
fg_enrich<-read.table(fg_enrich.path, sep="\t", header=TRUE, row.names=1)

mot_num = mot_num[ rowSums(mot_num)!=0, ]
protcount<-nrow(mot_num)

mots<-mots[order(mots$enrichment, decreasing = TRUE), ]
mots$enrichment<-round(mots$enrichment, 2)
if (nrow(mots)>12){
  kable(mots, row.names=FALSE, col.names=c("Motif", "Enrichment", "Count of proteins with motif", "Median  motif count per protein")) %>%
    kable_styling(bootstrap_options = c("striped", "hover", "condensed"), full_width = T) %>%
    column_spec(1, width = "5em") %>%
    column_spec(2, width = "6em") %>%
    column_spec(3, width = "15em") %>%
    column_spec(4, width = "18em") %>%
    scroll_box(width = "70%", height = "500px")
}else{
  kable(mots, row.names=FALSE, col.names=c("Motif", "Enrichment", "Count of proteins with motif", "Median  motif count per protein")) %>%
    kable_styling(bootstrap_options = c("striped", "hover", "condensed"), full_width = F, position = "left") %>%
    column_spec(1, width = "5em") %>%
    column_spec(2, width = "6em") %>%
    column_spec(3, width = "15em") %>%
    column_spec(4, width = "18em")
}

#'<br>
#'The data in the table above can be visualized as wordclouds. To avoid plotting problems, any infinitely enriched
#'motifs were first removed from the data. In this analyses we are not interested in the peculiarities of
#'particular proteins, but in the properties of this group of proteins as a whole, so any motifs found in less
#'than 5% of the proteins or in only one protein, were also removed before plotting.
#'
#'In the wordcoulds the height of the letters relates to either the number of proteins in the set of interest containing
#'a given motif (left), the enrichment of a motif relative to the background proteome (middle), or the product of the scaled values of
#'these two measures (right). In some datasets with very few motifs, the scaled values are numerically undefined and no wordcloud will be plotted.
#'

#+ echo = FALSE, warnings=FALSE, messages=FALSE
mots_finite<-subset(mots, enrichment!="Inf")
prots_5pc<-0.05*protcount
mots_finite<-subset(mots_finite, positiveprots >= prots_5pc & positiveprots > 1)

mots_finite$enrichment2<-mots_finite$enrichment
mots_finite$enrichment2[mots_finite$enrichment2 == 'Inf']<-1000000
mots_finite$enrichment2<-as.numeric(mots_finite$enrichment2)
mots_finite$enrichment_sca<- (mots_finite$enrichment2 - min(mots_finite$enrichment2)) / (max(mots_finite$enrichment2) - min(mots_finite$enrichment2))
mots_finite$positiveprots_sca<- (mots_finite$positiveprots - min(mots_finite$positiveprots)) / (max(mots_finite$positiveprots) - min(mots_finite$positiveprots))

mots_finite$scalprod<- (6 * mots_finite$enrichment_sca + 1) * (6 * mots_finite$positiveprots_sca + 1)

#+ echo = FALSE, warnings=FALSE, messages=FALSE, fig.height=3, fig.width=8
if(!anyNA(mots_finite$scalprod)){
	layout(matrix(c(1,2,3,4,5,6), nrow=2, byrow = TRUE), heights=c(0.7, 1.5))
	par(mar=rep(0, 4))
	plot.new()
	text(x=0.5, y=0.2, "Number of proteins\ncontaining motif", cex=1.5, pos=3)
	plot.new()
	text(x=0.5, y=0.2, "Enrichment", cex=1.5, pos=3)

	plot.new()
	text(x=0.5, y=0.2, "Product of scaled\nvalues", cex=1.5, pos=3)
	wordcloud(mots_finite$motif, mots_finite$positiveprots, scale=c(3, 0.2), random.order=FALSE, min.freq = 1, rot.per="0", colors= (brewer.pal(9, "YlOrRd")))

	wordcloud(mots_finite$motif, mots_finite$enrichment, scale=c(3, 0.2), min.freq = 1, random.order=FALSE, rot.per="0", colors= (brewer.pal(9, "YlOrRd")))

	wordcloud(mots_finite$motif, mots_finite$scalprod, scale=c(3, 0.2), random.order=FALSE, min.freq = 1, rot.per="0", colors= (brewer.pal(9, "YlOrRd")), main="product")
}

#+ echo = FALSE, message=FALSE, include=FALSE
if(!anyNA(mots_finite$scalprod)){
	svg(wclname)
	layout(matrix(c(1,2,3,4,5,6), nrow=2, byrow = TRUE), heights=c(0.7, 1.5))
	par(mar=rep(0, 4))
	plot.new()
	text(x=0.5, y=0.2, "Number of proteins\ncontaining motif", cex=1.5, pos=3)
	plot.new()
	text(x=0.5, y=0.2, "Enrichment", cex=1.5, pos=3)

	plot.new()
	text(x=0.5, y=0.2, "Product of scaled\nvalues", cex=1.5, pos=3)
	wordcloud(mots_finite$motif, mots_finite$positiveprots, scale=c(3, 0.2), random.order=FALSE, min.freq = 1, rot.per="0", colors= (brewer.pal(9, "YlOrRd")))

	wordcloud(mots_finite$motif, mots_finite$enrichment, scale=c(3, 0.2), min.freq = 1, random.order=FALSE, rot.per="0", colors= (brewer.pal(9, "YlOrRd")))

	wordcloud(mots_finite$motif, mots_finite$scalprod, scale=c(3, 0.2), random.order=FALSE, min.freq = 1, rot.per="0", colors= (brewer.pal(9, "YlOrRd")), main="product")

	dev.off()
}

#'<br>
#'In general there tends to be a negative correlation between the enrichment of a motif and the number of
#'proteins in which it is found. It is possible that motifs that deviate from this trend (ie they are
#'unusually enriched given the number of proteins in which they are found, or are in an unusually
#'large number of proteins given their enrichment) might have particular biological significance. The scatter
#'plots below plot the enrichment of the motifs against the number of proteins in which they are found (and vice versa)
#'to help you visualize any deviations from the expected negative correlation. If a linear regression is appropriate, a regression line (either linear or polynomial) is
#'shown in red and the shaded area represents the 95% confidence interval of the regression. No regression line is shown in cases with strong non-linearity.
#'Points are labelled only if there is sufficient space in the plot.
#'<br>
#+
#+ echo = FALSE, warnings=FALSE, messages=FALSE
enrich_pos.lm<-lm(mots_finite$enrichment ~ mots_finite$positiveprots)
lmr2<-summary(enrich_pos.lm)$r.squared
if(lmr2 > 0.95){
  method_fit<-TRUE
  }else{
  method_fit<-FALSE}

#+ echo = FALSE, warnings=FALSE, messages=FALSE

if(nrow(mots_finite) < 40 ){
  scat1<-ggplot(mots_finite, aes(enrichment, positiveprots))
  scat1<-scat1 + geom_point() + theme_classic() +
    {if(method_fit)geom_smooth(method = "lm", se = TRUE, show.legend = FALSE, aes(colour = "red"), weight = "1", fill = "#E5D0D0")} +
    geom_text_repel(aes(label = mots_finite$motif), size = 3.5) +
    labs(x="Fold motif enrichment", y = "Number of proteins containing motif")
  suppressWarnings(suppressMessages(print(scat1)))
}else{

    scat1<-ggplot(mots_finite, aes(enrichment, positiveprots))
    scat1<- scat1 + geom_point() + theme_classic() +
    {if(method_fit)geom_smooth(method = "lm", se = TRUE, show.legend = FALSE, aes(colour = "red"), weight = "1", fill = "#E5D0D0")} +
    labs(x="Fold motif enrichment", y = "Number of proteins containing motif")
    suppressWarnings(suppressMessages(print(scat1)))
}


#'<br>
#+ echo = FALSE, warnings=FALSE, messages=FALSE

if(nrow(mots_finite) < 40 ){
  scat2<-ggplot(mots_finite, aes( positiveprots, enrichment))
  scat2<-scat2 + geom_point() + theme_classic() +
    {if(method_fit)geom_smooth(method = "lm", se = TRUE, show.legend = FALSE, aes(colour = "red"), weight = "1", fill = "#E5D0D0")} +
    geom_text_repel(aes(label = mots_finite$motif), size = 3.5) +
    labs(y="Fold motif enrichment", x = "Number of proteins containing motif")
  suppressWarnings(suppressMessages(print(scat2)))
}else{
  scat2<-ggplot(mots_finite, aes( positiveprots, enrichment))
  scat2<-scat2 + geom_point() + theme_classic() +
    {if(method_fit)geom_smooth(method = "lm", se = TRUE, show.legend = FALSE, aes(colour = "red"), weight = "1", fill = "#E5D0D0")} +
    labs(y="Fold motif enrichment", x = "Number of proteins containing motif")
  suppressWarnings(suppressMessages(print(scat2)))

}



#'<br>
#'You may be interested in grouping or subdividing your PSOI based on the motif content of the proteins.
#'The heatmaps below provide a starting point for such approaches. In the first heatmap, proteins are clustered
#'based on motif enrichment in a given protein sequence with
#'respect the the background sequences, and motifs are clustered based on their enrichment amongst proteins.
#'Clustering is restricted to proteins displaying a high degree of compositional bias (depending on the value of the fLPS p-value parameter chosen by the user).
#'This is because a relationship between cluster membership and shared function has only been demonstrated for this class of proteins.
#'Infinitely enriched motifs, if present in the data, are excluded.
#'Clustering is further restricted to the 70 motifs with the greatest overall enrichment in this set, and a motif
#'must be found in at least 3 proteins to enter the clustering processes. This prevents the heatmap being dominated by motifs that are
#'extremely enriched, but only found in one or two proteins. This filter is not applied if the number of proteins is small (<10). Inevitably some proteins in the resulting data set have little similarity to
#'other proteins. To ensure we only group proteins that have true similarity, proteins are required to have a distance correlation of at
#'least 0.65 with one other protein in the data set to be inlcuded in the set for clustering.
#'Proteins containing none of the motifs are not displayed.

#+ echo = FALSE


bias<-read.table(bias.path, sep = "\t", header = TRUE)
bias$pval <- 1 / bias$invpval
biasids <- bias %>% filter(., pval < flpspval) %>% .$accession %>% as.vector() %>% unique()

#select proteins in biased list

fg_enrich<-rownames_to_column(fg_enrich, var = "prot")
fg_enrich<-fg_enrich %>% filter(., prot %in% biasids)
fg_enrich<-column_to_rownames(fg_enrich, var="prot")

HM2plotted<-0

#remove Inf motifs
if(nrow(fg_enrich) > 0){
mots_finite2<-subset(mots, enrichment!="Inf")
fg_enrich <- fg_enrich[, colnames(fg_enrich) %in% mots_finite2$motif]


#motifs in >= 3 proteins
if(nrow(fg_enrich) > 10){
  enrich_bin<-as.matrix(fg_enrich)
  enrich_bin[enrich_bin > 0]<-1
  fg_enrich2<-fg_enrich[, colSums(enrich_bin) >= 3]
  fg_enrich2<-as.matrix(fg_enrich2)
}else{
  fg_enrich2<-as.matrix(fg_enrich)
}


#most enriched motifs only

fg_enrich2<-fg_enrich2[,order(colSums(fg_enrich2),decreasing = TRUE)]
if(ncol(fg_enrich2) > 70){
fg_enrich2<-fg_enrich2[ , 1:70]
}

#proeins showing at least a certian correlation

if(nrow(fg_enrich2) > 3){
corrthresh<-dcorco
distthresh= 1 - corrthresh

corrmat<-dist2(fg_enrich2, pairwise_fun = function(x, y) 1 - dcor(x, y))

corrmat2<-as.matrix(corrmat)
diag(corrmat2)<-NA
mindists<-colMins(corrmat2, na.rm = TRUE)
corrmat.df<-as.data.frame(corrmat2)
Highcorrprots<-colnames(corrmat.df[,c(mindists < distthresh)])

fg_enrich3<-as.data.frame(fg_enrich2)
fg_enrich3<-rownames_to_column(fg_enrich3, var = "pro")
fg_enrich3<- fg_enrich3 %>% filter(., pro %in% Highcorrprots)
fg_enrich3<-column_to_rownames(fg_enrich3, var = "pro")
fg_enrich3_mat<-as.matrix(fg_enrich3)


if(nrow(fg_enrich3_mat) > 2){
fg_enrich3_mat = fg_enrich3_mat[ rowSums(fg_enrich3_mat)!=0, colSums(fg_enrich3_mat)!=0]


heat2height<-0.22*nrow(fg_enrich3_mat) + 13
heat2width<-0.27*ncol(fg_enrich3_mat) + 10.2




addnoise2vec<- function(m, noise){
    matdim<-dim(m)[1] * dim(m)[2]
    m<- m + runif(m, min = 0, max = noise)
  return(m)
}

fg_enrich3_mat<-addnoise2vec(fg_enrich3_mat, 0.0000005)

HM2plotted<-1
}
}
}

if(HM2plotted == 0){
  heat2height<-0.22*25 + 13
  heat2width<-0.27*10 + 10.2
}


#+ fig.height=heat2height, fig.width=heat2width, echo=FALSE, dpi = 50

if(HM2plotted == 1){
hmcol <- colorRampPalette(brewer.pal(9, "GnBu"), bias = 8)(100)


hm2_fakelen<-max(nchar(rownames(fg_enrich3_mat))) * 5
hm2_emptylab<-rep(" ", hm2_fakelen) %>% paste(., collapse='')
hm2_emptylab<-c(hm2_emptylab, ".") %>% paste(., collapse='')
col_fun = colorRamp2(c(0,   ncol(fg_enrich3_mat)), c("white", "white"))
hm2a = HeatmapAnnotation(foo = rep(0, ncol(fg_enrich3_mat)),
                         col = list(foo = col_fun),
                         annotation_label = hm2_emptylab,
                         simple_anno_size = unit(1, "mm"),
                         show_legend = FALSE)

HM_2<-Heatmap(fg_enrich3_mat,
        col = hmcol,
        #clustering_distance_rows = "euclidean",
        clustering_distance_rows = function(x, y) 1 - cor(x, y),
        clustering_method_rows = "ward.D",
        clustering_distance_columns =  function(x, y) 1 - cor(x, y),
        clustering_method_columns = "ward.D",
        row_names_gp = gpar(fontsize = 14),
        column_names_gp = gpar(fontsize = 14),
        row_dend_width = unit(3, "cm"),
        column_dend_height = unit(3, "cm"),
        top_annotation = hm2a,
        heatmap_legend_param = list(legend_width = unit(12, "cm"),
                                    title_position = 'topcenter',
                                    legend_direction = 'horizontal',
                                    title = "Fold motif enrichment",
                                    title_gp = gpar(fontsize = 18),
                                    labels_gp = gpar(fontsize = 14),
									labels_rot = 45
                                    ))

draw(HM_2, heatmap_legend_side = "top")

}

if(HM2plotted == 0){

  print("No Heatmap? This is because nsufficient proteins remained after application of the filters.")

}


#+ echo= FALSE


HM3plotted<-0

#most enriched motifs only
if(nrow(fg_enrich) > 0){
  fg_enrich4<-as.matrix(fg_enrich)
  fg_enrich4<-fg_enrich4[,order(colSums(fg_enrich4),decreasing = TRUE)]
  if(ncol(fg_enrich4) > 70){
    fg_enrich4<-fg_enrich[ , 1:70]
  }
  fg_enrich4<-as.matrix(fg_enrich)
}
#proeins showling at least a certian correlation
if(nrow(fg_enrich4) > 3){
corrthresh<-dcorco
distthresh= 1 - corrthresh

corrmat_b<-dist2(fg_enrich4, pairwise_fun = function(x, y) 1 - dcor(x, y))

corrmatb_2<-as.matrix(corrmat_b)
diag(corrmatb_2)<-NA
mindists<-colMins(corrmatb_2, na.rm = TRUE)
corrmat_b.df<-as.data.frame(corrmatb_2)
Highcorrprotsb<-colnames(corrmat_b.df[,c(mindists < distthresh)])

fg_enrich5<-as.data.frame(fg_enrich4)
fg_enrich5<-rownames_to_column(fg_enrich5, var = "pro")
fg_enrich5<- fg_enrich5 %>% filter(., pro %in% Highcorrprotsb)
fg_enrich5<-column_to_rownames(fg_enrich5, var = "pro")
fg_enrich5_mat<-as.matrix(fg_enrich5)


if(nrow(fg_enrich5_mat) > 2){
fg_enrich5_mat = fg_enrich5_mat[ rowSums(fg_enrich5_mat)!=0, colSums(fg_enrich5_mat)!=0]

heat3height<-0.22*nrow(fg_enrich5_mat) + 13
heat3width<-0.27*ncol(fg_enrich5_mat) + 10.2

HM3plotted<-1

}
}

#+
#'<br>
#'In the second heatmap, proteins are clustered based on motif enrichment exactly as in heatmap 1, except that
#'the filter requiring that motifs are found in at least 4 proteins is not applied. These heatmaps are therefore
#'more often dominated by unusally enriched motifs found in only one or two proteins.
#'
#'<br>

#+ echo=FALSE
if(HM3plotted == 0){
  heat3height<-0.22*25 + 13
  heat3width<-0.27*10 + 10.2

}


#+ fig.height=heat3height, fig.width=heat3width, echo=FALSE, dpi = 50

if(HM3plotted == 1){

fg_enrich5_mat<-addnoise2vec(fg_enrich5_mat, 0.0000005)

hm3_fakelen<-max(nchar(rownames(fg_enrich5_mat))) * 5
hm3_emptylab<-rep(" ", hm3_fakelen) %>% paste(., collapse='')
hm3_emptylab<-c(hm3_emptylab, ".") %>% paste(., collapse='')
col_fun = colorRamp2(c(0,   ncol(fg_enrich5_mat)), c("white", "white"))
hm3a = HeatmapAnnotation(foo = rep(0, ncol(fg_enrich5_mat)),
                         col = list(foo = col_fun),
                         annotation_label = hm3_emptylab,
                         simple_anno_size = unit(1, "mm"),
                         show_legend = FALSE)

HM_3<-Heatmap(fg_enrich5_mat,
              col = hmcol,
              #clustering_distance_rows = "euclidean",
              clustering_distance_rows = function(x, y) 1 - cor(x, y),
              clustering_method_rows = "ward.D",
              clustering_distance_columns =  function(x, y) 1 - cor(x, y),
              clustering_method_columns = "ward.D",
              row_names_gp = gpar(fontsize = 14),
              column_names_gp = gpar(fontsize = 14),
              row_dend_width = unit(3, "cm"),
              column_dend_height = unit(3, "cm"),
              top_annotation = hm3a,
              heatmap_legend_param = list(legend_width = unit(12, "cm"),
                                          title_position = 'topcenter',
                                          legend_direction = 'horizontal',
                                          title = "Fold motif enrichment",
                                          title_gp = gpar(fontsize = 18),
                                          labels_gp = gpar(fontsize = 14),
										  labels_rot = 45
              ))

draw(HM_3, heatmap_legend_side = "top")


}


if(HM3plotted == 0){

  print("No Heatmap? This is because insufficient proteins remained after application of the filters")

}


#+
#'<br>
#'In the third heatmap, proteins are clustered based on the absolute number of motifs. This heatmap is
#'intended as context for the previous two. It displays the same set of proteins and motifs as in heatmap 2.
#'<br>


#+ echo = FALSE

if(HM3plotted == 1){
mot_num2<-mot_num[ rownames(mot_num)  %in% rownames(fg_enrich5_mat) , colnames(mot_num)  %in% colnames(fg_enrich5_mat)]

mot_num2 <- mot_num2[ rowSums(mot_num2)!=0, ]
mot_num2 <- as.matrix(mot_num2)

heat1height<-0.22*nrow(mot_num2) + 13
heat1width<-0.27*ncol(mot_num2) + 10.2

mot_num2<-addnoise2vec(mot_num2, 0.02)

}


if(HM3plotted == 0){
  heat1height<-0.22*25 + 13
  heat1width<-0.27*10 + 10.2
}

#+ fig.height=heat1height, fig.width=heat1width, echo=FALSE, dpi = 50

if(HM3plotted == 1){


hmcol <- colorRampPalette(brewer.pal(9, "GnBu"), bias = 2)(100)

hm1_fakelen<-max(nchar(rownames(mot_num2))) * 5
hm1_emptylab<-rep(" ", hm1_fakelen) %>% paste(., collapse='')
hm1_emptylab<-c(hm1_emptylab, ".") %>% paste(., collapse='')
col_fun = colorRamp2(c(0,   ncol(mot_num2)), c("white", "white"))
hm1a = HeatmapAnnotation(foo = rep(0, ncol(mot_num2)),
                       col = list(foo = col_fun),
                       annotation_label = hm1_emptylab,
                       simple_anno_size = unit(1, "mm"),
                       show_legend = FALSE)

HM_1<-Heatmap(mot_num2,
              col = hmcol,
              #clustering_distance_rows = "euclidean",
              clustering_distance_rows = function(x, y) 1 - cor(x, y),
              clustering_method_rows = "ward.D",
              clustering_distance_columns =  function(x, y) 1 - cor(x, y),
              clustering_method_columns = "ward.D",
              row_names_gp = gpar(fontsize = 14),
              column_names_gp = gpar(fontsize = 14),
              row_dend_width = unit(3, "cm"),
              column_dend_height = unit(3, "cm"),
              row_names_max_width = max_text_width(rownames(mot_num2 * 2), gp=gpar(fontsize=14)),
              top_annotation = hm1a,
              heatmap_legend_param = list(legend_width = unit(6, "cm"),
                                          title_position = 'topcenter',
                                          legend_direction = 'horizontal',
                                          title = "Motif count",
                                          title_gp = gpar(fontsize = 18),
                                          labels_gp = gpar(fontsize = 14)
              ))

draw(HM_1, heatmap_legend_side = "top")



}



if(HM3plotted == 0){

  print("No Heatmap? This is because insufficient proteins remained after application of the filters")

}
